"use strict";

exports.buildPattern = buildPattern;
exports.buildRegExp = buildRegExp;
var _encoder = require("./encoder.js");
function buildRegExp(sequence, flags) {
  const pattern = (0, _encoder.encode)(sequence).pattern;
  const flagsString = encodeFlags(flags ?? {});
  if (!flags?.unicode) {
    const unicodeModePattern = getUnicodeModePattern(pattern);
    if (unicodeModePattern) {
      throw new Error(`The pattern "${unicodeModePattern}" requires Unicode-aware mode. Please ensure the "unicode" flag is set.`);
    }
  }
  return new RegExp(pattern, flagsString);
}
function buildPattern(sequence) {
  return (0, _encoder.encode)(sequence).pattern;
}
function encodeFlags(flags) {
  let result = '';
  if (flags.global) result += 'g';
  if (flags.ignoreCase) result += 'i';
  if (flags.multiline) result += 'm';
  if (flags.hasIndices) result += 'd';
  if (flags.dotAll) result += 's';
  if (flags.sticky) result += 'y';
  if (flags.unicode) result += 'u';
  return result;
}
const unicodeModePatterns = /(?:\\u|\\p|\\P)\{.+?\}/;
function getUnicodeModePattern(pattern) {
  const match = pattern.match(unicodeModePatterns);
  return match?.[0] ?? null;
}
//# sourceMappingURL=builders.js.map