"use strict";

exports.any = void 0;
exports.char = char;
exports.notWord = exports.notWhitespace = exports.notDigit = exports.nonWord = exports.nonWhitespace = exports.nonDigit = exports.digit = void 0;
exports.unicodeProperty = unicodeProperty;
exports.word = exports.whitespace = void 0;
const any = exports.any = {
  precedence: 'atom',
  pattern: '.'
};
const digit = exports.digit = {
  precedence: 'atom',
  pattern: '\\d',
  chars: ['\\d']
};
const nonDigit = exports.nonDigit = {
  precedence: 'atom',
  pattern: '\\D',
  chars: ['\\D']
};
const word = exports.word = {
  precedence: 'atom',
  pattern: '\\w',
  chars: ['\\w']
};
const nonWord = exports.nonWord = {
  precedence: 'atom',
  pattern: '\\W',
  chars: ['\\W']
};
const whitespace = exports.whitespace = {
  precedence: 'atom',
  pattern: '\\s',
  chars: ['\\s']
};
const nonWhitespace = exports.nonWhitespace = {
  precedence: 'atom',
  pattern: '\\S',
  chars: ['\\S']
};
const notDigit = exports.notDigit = nonDigit;
const notWord = exports.notWord = nonWord;
const notWhitespace = exports.notWhitespace = nonWhitespace;
function char(codePoint) {
  if (!Number.isInteger(codePoint) || codePoint < 0 || codePoint > 0x10ffff) {
    throw new RangeError(`Expected a valid unicode code point but received ${codePoint}`);
  }
  let escape = codePoint < 0x10000 ? `\\u${codePoint.toString(16).padStart(4, '0')}` : `\\u{${codePoint.toString(16)}}`;
  return {
    precedence: 'atom',
    pattern: escape,
    chars: [escape]
  };
}
function unicodeProperty(property, value) {
  const escape = `\\p{${property}${value ? `=${value}` : ''}}`;
  return {
    precedence: 'atom',
    pattern: escape,
    chars: [escape]
  };
}
//# sourceMappingURL=char-escape.js.map