import type { CharacterEscape, EncodedRegex } from '../types';
/**
 * Matches any single character.
 * Specifically this one is NOT a character escape.
 */
export declare const any: EncodedRegex;
export declare const digit: CharacterEscape;
export declare const nonDigit: CharacterEscape;
export declare const word: CharacterEscape;
export declare const nonWord: CharacterEscape;
export declare const whitespace: CharacterEscape;
export declare const nonWhitespace: CharacterEscape;
/**
 * @deprecated Renamed to `nonDigit`.
 */
export declare const notDigit: CharacterEscape;
/**
 * @deprecated Renamed to `nonWord`.
 */
export declare const notWord: CharacterEscape;
/**
 * @deprecated Renamed to `nonWhitespace`.
 */
export declare const notWhitespace: CharacterEscape;
/**
 * Unicode character code point escape.
 *
 * Regex pattern:
 * - `\uXXXX`: 4-digit hex escape for code points below 0x10000.
 * - `\u{X}`: Unicode code point escape for code points above 0xFFFF.
 *
 * Note: for code points above 0xFFFF, the regex must be [unicode-aware](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/RegExp/unicode#unicode-aware_mode).
 *
 * @param codePoint The code point of the character to escape.
 * @returns A character class representing the unicode escape.
 */
export declare function char(codePoint: number): CharacterEscape;
/**
 * Unicode property escape matching a set of characters specified by a Unicode property.
 *
 * Regex pattern: `\p{Property}` or `\p{Property=Value}`
 * @see https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Regular_expressions/Unicode_character_class_escape
 *
 * Note: the regex must be [unicode-aware](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/RegExp/unicode#unicode-aware_mode).
 *
 * @param property Unicode property name.
 * @param value Unicode property value (optional).
 * @returns A character class representing the unicode property escape.
 */
export declare function unicodeProperty(property: string, value?: string): CharacterEscape;
